==> slayersbeasts-fabric-1.21.1-5.2.0-sources.jar: net/invictusslayer/slayersbeasts/world/level/block/InfusedCryptalithBlock.java <==
package net.invictusslayer.slayersbeasts.world.level.block;

import com.google.common.base.Predicates;
import net.invictusslayer.slayersbeasts.registries.SBBlocks;
import net.minecraft.class_10;
import net.minecraft.class_1750;
import net.minecraft.class_1937;
import net.minecraft.class_2248;
import net.minecraft.class_2338;
import net.minecraft.class_2350;
import net.minecraft.class_2383;
import net.minecraft.class_2398;
import net.minecraft.class_2680;
import net.minecraft.class_2689;
import net.minecraft.class_2694;
import net.minecraft.class_2697;
import net.minecraft.class_2700;
import net.minecraft.class_2715;
import net.minecraft.class_2741;
import net.minecraft.class_2746;
import net.minecraft.class_2753;
import net.minecraft.class_5819;

public class InfusedCryptalithBlock extends class_2248 {
	public static final class_2753 FACING = class_2383.field_11177;
	public static final class_2746 ACTIVE = class_2741.field_12488;
	private static class_2700 portalShape;
	
	public InfusedCryptalithBlock(class_2251 properties) {
		super(properties);
		this.method_9590(this.field_10647.method_11664().method_11657(FACING, class_2350.field_11043).method_11657(ACTIVE, false));
	}

	protected void method_9515(class_2689.class_2690<class_2248, class_2680> builder) {
		builder.method_11667(FACING, ACTIVE);
	}

	public class_2680 method_9605(class_1750 context) {
		return method_9564().method_11657(FACING, context.method_8042().method_10153()).method_11657(ACTIVE, false);
	}

	public static class_2700 getOrCreatePortalShape() {
		if (portalShape == null) {
			portalShape = class_2697.method_11701().method_11702("?vv?", ">??<", ">??<", "?^^?")
					.method_11700('?', class_2694.method_11678(class_2715.field_12419))
					.method_11700('^', class_2694.method_11678(class_2715.method_11758(SBBlocks.INFUSED_CRYPTALITH.get())
							.method_11762(ACTIVE, Predicates.equalTo(true)).method_11762(FACING, Predicates.equalTo(class_2350.field_11035))))
					.method_11700('>', class_2694.method_11678(class_2715.method_11758(SBBlocks.INFUSED_CRYPTALITH.get())
							.method_11762(ACTIVE, Predicates.equalTo(true)).method_11762(FACING, Predicates.equalTo(class_2350.field_11039))))
					.method_11700('v', class_2694.method_11678(class_2715.method_11758(SBBlocks.INFUSED_CRYPTALITH.get())
							.method_11762(ACTIVE, Predicates.equalTo(true)).method_11762(FACING, Predicates.equalTo(class_2350.field_11043))))
					.method_11700('<', class_2694.method_11678(class_2715.method_11758(SBBlocks.INFUSED_CRYPTALITH.get())
							.method_11762(ACTIVE, Predicates.equalTo(true)).method_11762(FACING, Predicates.equalTo(class_2350.field_11034)))).method_11704();
		}

		return portalShape;
	}

	public boolean method_9516(class_2680 state, class_10 type) {
		return false;
	}

	public void method_9496(class_2680 state, class_1937 level, class_2338 pos, class_5819 random) {
		double d0 = pos.method_10263() + random.method_43058();
		double d1 = pos.method_10264() + 0.8D;
		double d2 = pos.method_10260() + random.method_43058();
		level.method_8406(class_2398.field_23956, d0, d1, d2, 0.0D, 0.0D, 0.0D);
	}
}

==> slayersbeasts-fabric-1.21.4-6.2.0-sources.jar: net/invictusslayer/slayersbeasts/world/level/block/InfusedCryptalithBlock.java <==
package net.invictusslayer.slayersbeasts.world.level.block;

import com.google.common.base.Predicates;
import net.invictusslayer.slayersbeasts.registries.SBBlocks;
import net.minecraft.class_10;
import net.minecraft.class_1750;
import net.minecraft.class_1937;
import net.minecraft.class_2248;
import net.minecraft.class_2338;
import net.minecraft.class_2350;
import net.minecraft.class_2383;
import net.minecraft.class_2398;
import net.minecraft.class_2680;
import net.minecraft.class_2689;
import net.minecraft.class_2694;
import net.minecraft.class_2697;
import net.minecraft.class_2700;
import net.minecraft.class_2715;
import net.minecraft.class_2741;
import net.minecraft.class_2746;
import net.minecraft.class_2754;
import net.minecraft.class_5819;

public class InfusedCryptalithBlock extends class_2248 {
	public static final class_2754<class_2350> FACING = class_2383.field_11177;
	public static final class_2746 ACTIVE = class_2741.field_55087;
	private static class_2700 portalShape;
	
	public InfusedCryptalithBlock(class_2251 properties) {
		super(properties);
		this.method_9590(this.field_10647.method_11664().method_11657(FACING, class_2350.field_11043).method_11657(ACTIVE, false));
	}

	protected void method_9515(class_2689.class_2690<class_2248, class_2680> builder) {
		builder.method_11667(FACING, ACTIVE);
	}

	public class_2680 method_9605(class_1750 context) {
		return method_9564().method_11657(FACING, context.method_8042().method_10153()).method_11657(ACTIVE, false);
	}

	public static class_2700 getOrCreatePortalShape() {
		if (portalShape == null) {
			portalShape = class_2697.method_11701().method_11702("?vv?", ">??<", ">??<", "?^^?")
					.method_11700('?', class_2694.method_11678(class_2715.field_12419))
					.method_11700('^', class_2694.method_11678(class_2715.method_11758(SBBlocks.INFUSED_CRYPTALITH.get())
							.method_11762(ACTIVE, Predicates.equalTo(true)).method_11762(FACING, Predicates.equalTo(class_2350.field_11035))))
					.method_11700('>', class_2694.method_11678(class_2715.method_11758(SBBlocks.INFUSED_CRYPTALITH.get())
							.method_11762(ACTIVE, Predicates.equalTo(true)).method_11762(FACING, Predicates.equalTo(class_2350.field_11039))))
					.method_11700('v', class_2694.method_11678(class_2715.method_11758(SBBlocks.INFUSED_CRYPTALITH.get())
							.method_11762(ACTIVE, Predicates.equalTo(true)).method_11762(FACING, Predicates.equalTo(class_2350.field_11043))))
					.method_11700('<', class_2694.method_11678(class_2715.method_11758(SBBlocks.INFUSED_CRYPTALITH.get())
							.method_11762(ACTIVE, Predicates.equalTo(true)).method_11762(FACING, Predicates.equalTo(class_2350.field_11034)))).method_11704();
		}

		return portalShape;
	}

	public boolean method_9516(class_2680 state, class_10 type) {
		return false;
	}

	public void method_9496(class_2680 state, class_1937 level, class_2338 pos, class_5819 random) {
		double d0 = pos.method_10263() + random.method_43058();
		double d1 = pos.method_10264() + 0.8D;
		double d2 = pos.method_10260() + random.method_43058();
		level.method_8406(class_2398.field_23956, d0, d1, d2, 0.0D, 0.0D, 0.0D);
	}
}
